==> JOB-3.1.2.tar.gz: JOB-3.1.2/event/src/com/ooc/CosEventServer/Server.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1997
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package com.ooc.CosEventServer;

import org.omg.CORBA.*;
import org.omg.CosEventChannelAdmin.*;
import java.util.*;

public class Server
{
    public static void
    main(String args[])
    {
	Properties props = System.getProperties();
	props.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
	props.put("org.omg.CORBA.ORBSingletonClass",
		  "com.ooc.CORBA.ORBSingleton");
	System.setProperties(props);

        try
        {
	    //
	    // Set the program name
	    //
	    String progName = "com.ooc.CosEventServer.Server";
	    
	    boolean typedService = false;
	    int i;

            //
            // Create ORB.
            //
            ORB orb = ORB.init(args, props);
 
	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.ORB)orb).filter_options(args);

	    //
	    // Prescan the arguments to determine if we're running the
	    // typed event service or the untyped.
	    //
	    for(i = 0; i < args.length; i++)
	    {
		if(args[i].equals("--typed-service") ||
		   args[i].equals("-t"))
		{
		    typedService = true;
		}
		else if(args[i].equals("--untyped-service") ||
			args[i].equals("-u"))
		{
		    typedService = false;
		}
	    }

	    //
	    // Resolve the service object if available as an initial
	    // reference.
	    //
	    String service = (typedService)
		? "TypedEventService"
		: "EventService";
	    org.omg.CORBA.Object serviceObject = null;
	    try
	    {
		serviceObject = orb.resolve_initial_references(service);
	    }
	    catch(org.omg.CORBA.ORBPackage.InvalidName e)
	    {
	    }

	    //
	    // Set the IIOP port based on the port defined in the IIOP
	    // profile of the service object (if it exists). Then
	    // create the BOA.
	    //
	    com.ooc.CORBA.BOA.set_iiop_port_from_object(serviceObject);
	    BOA boa = ((com.ooc.CORBA.ORB)orb).BOA_init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.BOA)boa).filter_options(args);

	    //
	    // We have to run the BOA in either thread-per-client,
	    // thread-pool or thread-per-request concurrency model.
	    //
	    ((com.ooc.CORBA.ORB)orb).conc_model(
		com.ooc.CORBA.ORB.ConcModel.ConcModelBlocking);
	    com.ooc.CORBA.BOA.ConcModel model =
		((com.ooc.CORBA.BOA)boa).conc_model();
	    if(model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerClient &&
	       model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPool &&
	       model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerRequest)
	    {
		((com.ooc.CORBA.BOA)boa).
		    conc_model(com.ooc.CORBA.BOA.ConcModel.
			       ConcModelThreadPerClient);
	    }

	    //
	    // Get options.
	    //
	    boolean ior = false;

	    for(i = 0 ; i < args.length && args[i].startsWith("-") ; i++)
	    {
		if(args[i].equals("--help") ||
		   args[i].equals("-h"))
		{
		    usage(progName);
		    System.exit(0);
		}
		else if(args[i].equals("--version") ||
			args[i].equals("-v"))
		{
                    System.err.println("Event Service " +
                                       com.ooc.CORBA.Version.version);
		    System.exit(0);
		}
		else if(args[i].equals("--ior") ||
			args[i].equals("-i"))
		{
		    ior = true;
		}
		else if(args[i].equals("--typed-service") ||
			args[i].equals("-t") ||
			args[i].equals("--untyped-service") ||
			args[i].equals("-u"))
		{
		    // ignore
		}
		else
		{
		    System.out.println(progName + ": unknown option `" +
				       args[i] + "'\n");
		    usage(progName);
		    System.exit(1);
		}
	    }

	    //
	    // Create event channel.
	    //
	    org.omg.CosEventChannelAdmin.EventChannel untypedChannel;
	    org.omg.CosTypedEventChannelAdmin.TypedEventChannel typedChannel;
	    com.ooc.EventServerAdmin eventServerAdmin;

	    String s;

	    if(!typedService)
	    {
		untypedChannel =
		    new com.ooc.CosEventChannelAdmin.impl.EventChannel(orb);
		((com.ooc.CORBA.ORB)orb).connect(untypedChannel,
						 "DefaultEventChannel");
		s = orb.object_to_string(untypedChannel);
		eventServerAdmin = new EventServerAdmin(boa, untypedChannel);
	    }
	    else
	    {
		try
		{
		    org.omg.CORBA.Object ir =
			orb.resolve_initial_references("InterfaceRepository");
		}
		catch(org.omg.CORBA.ORBPackage.InvalidName e)
		{
		    System.err.println(progName +
				       ": no `InterfaceRepository' initial " +
				       "reference.");
		    System.exit(1);
		}
		
		typedChannel = new com.ooc.CosTypedEventChannelAdmin.
		    impl.TypedEventChannel(orb);
		((com.ooc.CORBA.ORB)orb).
		    connect(typedChannel, "DefaultTypedEventChannel");
		s = orb.object_to_string(typedChannel);
		eventServerAdmin = new EventServerAdmin(boa, typedChannel);
	    }

	    ((com.ooc.CORBA.ORB)orb).
		connect(eventServerAdmin, "DefaultEventServerAdmin");

	    //
	    // Ensure everything is ready to run when the IOR is
	    // displayed.
	    //
	    ((com.ooc.CORBA.BOA)boa).init_servers();

	    //
	    // Print IOR on standard output.
	    //
	    if(ior)
		System.out.println(s);
 
	    //
	    // Run implementation.
	    //
	    boa.impl_is_ready(null);
        }
        catch(SystemException ex)
        {
	    ex.printStackTrace();
            System.exit(1);
        }

	System.exit(0);
    }

    static void
    usage(String progName)
    {
	System.err.println("Usage:");
	System.err.println(progName + " [options]\n" +
			   "\n" +
			   "Options:\n" +
			   "-h, --help             " +
			   "Show this message.\n" +
			   "-v, --version          " +
			   "Show Event Service version.\n" +
			   "-i, --ior              " +
			   "Print IOR on standard output." +
			   "-t, --typed-service    " +
			   "Run typed event service.\n" +
			   "-u, --untyped-service  " +
			   "Run untyped event service [default].\n");
    }
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/event/src/com/ooc/CosEventServer/Server.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package com.ooc.CosEventServer;

import org.omg.CORBA.*;
//import org.omg.CosEventChannelAdmin.*;
import java.util.*;

public class Server
{
    public static void
    main(String args[])
    {
	Properties props = System.getProperties();
	props.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
	props.put("org.omg.CORBA.ORBSingletonClass",
		  "com.ooc.CORBA.ORBSingleton");
	System.setProperties(props);

        try
        {
	    boolean typedService = false;
	    int i;
	    
            //
	    // Set the program name
	    //
	    String progName = "com.ooc.CosEventServer.Server";

            //
            // Create ORB.
            //
            ORB orb = ORB.init(args, props);
 
	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.ORB)orb).filter_options(args);

	    //
	    // Prescan the arguments to determine if we're running the
	    // typed event service or the untyped.
	    //
	    for(i = 0; i < args.length; i++)
	    {
		if(args[i].equals("--typed-service") ||
		   args[i].equals("-t"))
		{
		    typedService = true;
		}
		else if(args[i].equals("--untyped-service") ||
			args[i].equals("-u"))
		{
		    typedService = false;
		}
	    }

	    //
	    // Resolve the service object if available as an initial
	    // reference.
	    //
	    String service = (typedService)
		? "TypedEventService"
		: "EventService";
	    org.omg.CORBA.Object serviceObject = null;
	    try
	    {
		serviceObject = orb.resolve_initial_references(service);
	    }
	    catch(org.omg.CORBA.ORBPackage.InvalidName e)
	    {
	    }

	    //
	    // Set the IIOP port based on the port defined in the IIOP
	    // profile of the service object (if it exists). Then
	    // create the BOA.
	    //
	    com.ooc.CORBA.BOA.set_iiop_port_from_object(serviceObject);
	    BOA boa = ((com.ooc.CORBA.ORB)orb).BOA_init(args, props);

	    //
	    // Filter options.
	    //
	    args = ((com.ooc.CORBA.BOA)boa).filter_options(args);

	    //
	    // We have to run the BOA in either thread-per-client,
	    // thread-pool or thread-per-request concurrency model.
	    //
	    ((com.ooc.CORBA.ORB)orb).conc_model(
		com.ooc.CORBA.ORB.ConcModel.ConcModelBlocking);
	    com.ooc.CORBA.BOA.ConcModel model =
		((com.ooc.CORBA.BOA)boa).conc_model();
	    if(model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerClient &&
	       model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPool &&
	       model != com.ooc.CORBA.BOA.ConcModel.ConcModelThreadPerRequest)
	    {
		((com.ooc.CORBA.BOA)boa).
		    conc_model(com.ooc.CORBA.BOA.ConcModel.
			       ConcModelThreadPerClient);
	    }

	    //
	    // Get options.
	    //
	    boolean ior = false;

	    for(i = 0 ; i < args.length && args[i].startsWith("-") ; i++)
	    {
		if(args[i].equals("--help") ||
		   args[i].equals("-h"))
		{
		    usage(progName);
		    System.exit(0);
		}
		else if(args[i].equals("--version") ||
			args[i].equals("-v"))
		{
                    System.err.println("ORBacus Event Service " +
                                       com.ooc.CORBA.Version.version);
		    System.exit(0);
		}
		else if(args[i].equals("--ior") ||
			args[i].equals("-i"))
		{
		    ior = true;
		}
		else if(args[i].equals("--typed-service") ||
			args[i].equals("-t") ||
			args[i].equals("--untyped-service") ||
			args[i].equals("-u"))
		{
		    // ignore
		}
		else
		{
		    System.out.println(progName + ": unknown option `" +
				       args[i] + "'\n");
		    usage(progName);
		    System.exit(1);
		}
	    }

	    //
	    // Create event service.
	    //

	    String s;
	    EventService untyped = null;
	    TypedEventService typed = null;

	    if(!typedService)
	    {
		untyped = new EventService(orb, boa);
		untyped.initialize();

		com.ooc.OBEventChannelFactory.EventChannelFactory
		    untypedFactory = untyped.eventChannelFactory();
		org.omg.CosEventChannelAdmin.EventChannel untypedChannel = null;
		try
		{
		    untypedChannel =
			untypedFactory.create_channel("DefaultEventChannel");
		}
		catch(com.ooc.OBEventChannelFactory.ChannelAlreadyExists e)
		{
		    System.err.println(progName +
		    		       ": `DefaultEventChannel' " +
				       "already exists.");
		    System.exit(1);
		}

		s = orb.object_to_string(untypedChannel);
	    }
	    else
	    {
		try
		{
		    org.omg.CORBA.Object ir =
			orb.resolve_initial_references("InterfaceRepository");
		}
		catch(org.omg.CORBA.ORBPackage.InvalidName e)
		{
		    System.err.println(progName +
				       ": no `InterfaceRepository' initial " +
				       "reference.");
		    System.exit(1);
		}

		typed = new TypedEventService(orb, boa);
		typed.initialize();

		com.ooc.OBTypedEventChannelFactory.TypedEventChannelFactory
		    typedFactory = typed.typedEventChannelFactory();
		org.omg.CosTypedEventChannelAdmin.TypedEventChannel
		    typedChannel = null;
		try
		{
		    typedChannel =
			typedFactory.create_channel("DefaultTypedEventChannel");
		}
		catch(com.ooc.OBEventChannelFactory.ChannelAlreadyExists e)
		{
		    System.err.println(progName +
		    		       ": `DefaultTypedEventChannel' " +
				       "already exists.");
		    System.exit(1);
		}

		s = orb.object_to_string(typedChannel);
	    }

	    //
	    // Ensure everything is ready to run when the IOR is
	    // displayed.
	    //
	    ((com.ooc.CORBA.BOA)boa).init_servers();
	    
	    //
	    // Print IOR on standard output.
	    //
	    if(ior)
		System.out.println(s);
 
	    //
	    // Run implementation.
	    //
	    boa.impl_is_ready(null);

	    //
	    // Destroy the event service
	    //
	    if(!typedService)
		untyped.shutdown();
	    else
		typed.shutdown();
        }
        catch(SystemException ex)
        {
	    ex.printStackTrace();
            System.exit(1);
        }

	System.exit(0);
    }

    static void
    usage(String progName)
    {
	System.err.println("Usage:");
	System.err.println(progName + " [options]\n" +
			   "\n" +
			   "Options:\n" +
			   "-h, --help             " +
			   "Show this message.\n" +
			   "-v, --version          " +
			   "Show Event Service version.\n" +
			   "-i, --ior              " +
			   "Print IOR on standard output.\n" +
			   "-t, --typed-service    " +
			   "Run typed event service.\n" +
			   "-u, --untyped-service  " +
			   "Run untyped event service [default].\n");
    }
}
